


ibmdbpy4nps - Custom Python ML/Analytics Inside Netezza

  Please check the full documentation here
  https://rtpdoc01.rtp.raleigh.ibm.com:9443/kc/SS5FPD_next/com.ibm.ips.doc/postgresql/pyida/pyida.html

